# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum

import winrt.system
from winrt import _winrt_windows_gaming_input_preview

__all__ = [
    "DeviceCommand",
    "GameControllerBatteryChargingState",
    "GameControllerBatteryKind",
    "GameControllerBatteryLevel",
    "GameControllerFirmwareCorruptReason",
    "HeadsetLevel",
    "HeadsetOperation",
    "RemappingButtonCategory",
    "HeadsetGeqGains",
    "GameControllerProviderInfo",
    "LegacyGipGameControllerProvider",
]

class DeviceCommand(enum.IntEnum):
    RESET = 0

class GameControllerBatteryChargingState(enum.IntEnum):
    UNKNOWN = 0
    INACTIVE = 1
    ACTIVE = 2
    ERROR = 3

class GameControllerBatteryKind(enum.IntEnum):
    UNKNOWN = 0
    NONE = 1
    STANDARD = 2
    RECHARGEABLE = 3

class GameControllerBatteryLevel(enum.IntEnum):
    UNKNOWN = 0
    CRITICAL = 1
    LOW = 2
    MEDIUM = 3
    FULL = 4

class GameControllerFirmwareCorruptReason(enum.IntEnum):
    UNKNOWN = 0
    NOT_CORRUPT = 1
    TWO_UP_CORRUPT = 2
    APP_CORRUPT = 3
    RADIO_CORRUPT = 4
    EEPROM_CORRUPT = 5
    SAFE_TO_UPDATE = 6

class HeadsetLevel(enum.IntEnum):
    OFF = 0
    LOW = 1
    MEDIUM = 2
    HIGH = 3

class HeadsetOperation(enum.IntEnum):
    GEQ = 0
    BASS_BOOST_GAIN = 1
    SMART_MUTE = 2
    SIDE_TONE = 3
    MUTE_LED_BRIGHTNESS = 4
    SWAP_MIX_AND_VOLUME_DIALS = 5

class RemappingButtonCategory(enum.IntEnum):
    BUTTON_SETTINGS = 0
    ANALOG_SETTINGS = 1
    VIBRATION_SETTINGS = 2
    SHARE_SHORT_PRESS = 3
    SHARE_SHORT_PRESS_META_DATA = 4
    SHARE_SHORT_PRESS_META_DATA_DISPLAY = 5
    SHARE_LONG_PRESS = 6
    SHARE_LONG_PRESS_META_DATA = 7
    SHARE_LONG_PRESS_META_DATA_DISPLAY = 8
    SHARE_DOUBLE_PRESS = 9
    SHARE_DOUBLE_PRESS_META_DATA = 10
    SHARE_DOUBLE_PRESS_META_DATA_DISPLAY = 11

HeadsetGeqGains = _winrt_windows_gaming_input_preview.HeadsetGeqGains
GameControllerProviderInfo = _winrt_windows_gaming_input_preview.GameControllerProviderInfo
LegacyGipGameControllerProvider = _winrt_windows_gaming_input_preview.LegacyGipGameControllerProvider
